@@ -3,7 +3,7 @@ App::YTDL::YTDownload;
 
 use warnings;
 use strict;
-use 5.10.1;
+use 5.010001;
 
 use Exporter qw( import );
 our @EXPORT_OK = qw( download_youtube );
